@@ -5,7 +5,7 @@ InvoiceList = function (params) {
         addItemUrl = params.addItemUrl,
         target = params.target;
 
-    function handleListItemSelected(event, itemId) {
+    function handleListItemSelected(event, itemId, params) {
 
         var data = {};
 
@@ -15,12 +15,14 @@ InvoiceList = function (params) {
             url: addItemUrl,
             method: 'POST',
             data: data,
-            success: handleAddItemSuccess,
+            success: function (response) {
+                handleAddItemSuccess(response, params || {});
+            },
             error: handleAddItemError
         });
     }
 
-    function handleAddItemSuccess(response) {
+    function handleAddItemSuccess(response, params) {
         var $items = getItemsContainer(),
             $item = getItemContainer(response.item_id);
 
@@ -30,7 +32,11 @@ InvoiceList = function (params) {
             $items.prepend(response.html);
         }
 
-        getItemContainer(response.item_id).find('[data-role=qty-input]').focus();
+        if (params.focus) {
+            getItemContainer(response.item_id)
+                .find('[data-role=qty-input]')
+                .focus();
+        }
 
         $(window).trigger(target + '-updated', response[target]);
         $(window).trigger(target + '-total-updated', response.total);
@@ -77,6 +83,7 @@ InvoiceList = function (params) {
     new DeleteAction({
         $container: $container,
         selector: '[data-role=delete-action]',
+        method: 'DELETE',
         onDelete: function (itemId, response) {
             getItemContainer(itemId).remove();
             $(window).trigger(target + '-updated', response[target]);
