@@ -58,9 +58,12 @@ def update_invoice(request, invoice_type, invoice_id):
 @api_view(['POST'])
 def add_item(request, invoice_type, invoice_id):
 
-    invoice = request.invoices.get_invoice(invoice_type, invoice_id)
-    product = Product.objects.get(pk=request.data['product'])
-    item = invoice.add_item(product)
+    try:
+        invoice = request.invoices.get_invoice(invoice_type, invoice_id)
+        product = Product.objects.get(pk=request.data['product'])
+        item = invoice.add_item(product)
+    except ValueError as e:
+        return HttpResponseBadRequest(str(e))
 
     return Response({
         'status': 'OK',
